<p align="center">
<a href="https://github.com/meanii/Search4">
<img src="https://media.discordapp.net/attachments/749199487854968843/775966094670037012/IMG_20200828_114636_438.jpg" alt="search4"></a>

> An OSINT tool that helps you to find people on the internet. It's small and fast!
</p>

<hr>

#### Prerequisites

- [Install python3 as per your distro.](https://realpython.com/installing-python)

Installing search4

- Now you can install search4 using git:

```
pip3 install -U search4
```

Or, if you already downloaded search4, you can install it directly from the directory:
```
pip3 install .
```

You can use the `-e` flag to install the project in editable mode (i.e. setuptools "develop mode") from a local project path or a VCS url.

<hr>

#### Demo

```
search4 -u username
```

<a href="https://asciinema.org/a/384004">
<img src="https://media.discordapp.net/attachments/749199487854968843/798402820163239956/image0.png"></a>

---
###  Copyright & License
- Copyright (C)  2022 [meanii](https://github.om/meanii )
- Licensed under the terms of the [GNU General Public License v3.0](https://github.com/meanii/Search4/blob/master/LICENSE)